pub fn stub_depth(levels: usize) -> OrderBookDepthExpand description
Creates a depth snapshot with the requested number of levels per side.
pub fn stub_depth(levels: usize) -> OrderBookDepthCreates a depth snapshot with the requested number of levels per side.